@@ -43,13 +43,13 @@ check_df_visit <- function(df_visit) {
 
   cols_na <- df_visit %>%
     summarise_at(
-        vars(
-          .data$study_id,
-          .data$site_number,
-          .data$patnum,
-          .data$n_ae,
-          .data$visit
-        ),
+        vars(c(
+          "study_id",
+          "site_number",
+          "patnum",
+          "n_ae",
+          "visit"
+        )),
         anyNA
       ) %>%
     unlist()
@@ -60,10 +60,10 @@ check_df_visit <- function(df_visit) {
 
     df_visit %>%
       summarise_at(
-        vars(
-          .data$n_ae,
-          .data$visit
-        ),
+        vars(c(
+          "n_ae",
+          "visit"
+        )),
         ~ is.numeric(.)
       ) %>%
       unlist() %>%
@@ -129,13 +129,13 @@ exp_implicit_missing_visits <- function(df_visit) {
     group_by(.data$study_id) %>%
     mutate(min_study_visit = min(.data$visit),
               max_study_visit = max(.data$visit)) %>%
-    select(
-      .data$study_id,
-      .data$site_number,
-      .data$patnum,
-      .data$min_study_visit,
-      .data$max_study_visit
-    ) %>%
+    select(c(
+      "study_id",
+      "site_number",
+      "patnum",
+      "min_study_visit",
+      "max_study_visit"
+    )) %>%
     distinct() %>%
     mutate(
       visit = map2(
@@ -144,14 +144,14 @@ exp_implicit_missing_visits <- function(df_visit) {
         function(x, y) seq(x, y, 1)
       )
     ) %>%
-    unnest(.data$visit) %>%
-    select(
-      .data$study_id,
-      .data$site_number,
-      .data$patnum,
-      .data$min_study_visit,
-      .data$visit
-    )
+    unnest("visit") %>%
+    select(c(
+      "study_id",
+      "site_number",
+      "patnum",
+      "min_study_visit",
+      "visit"
+    ))
 
   df_visit_out <- df_visit %>%
     group_by(.data$study_id, .data$site_number, .data$patnum) %>%
@@ -164,7 +164,7 @@ exp_implicit_missing_visits <- function(df_visit) {
     ) %>%
     group_by(.data$study_id, .data$site_number, .data$patnum) %>%
     arrange(.data$visit) %>%
-    fill(.data$n_ae, .direction = "down") %>%
+    fill("n_ae", .direction = "down") %>%
     mutate(
       min_visit_pat = min(.data$min_visit_pat, na.rm = TRUE),
       max_visit_pat = max(.data$max_visit_pat, na.rm = TRUE)
@@ -177,13 +177,13 @@ exp_implicit_missing_visits <- function(df_visit) {
       .data$visit <= .data$max_visit_pat
     ) %>%
     mutate(n_ae = ifelse(is.na(.data$n_ae), 0, .data$n_ae)) %>%
-    select(
-      .data$study_id,
-      .data$site_number,
-      .data$patnum,
-      .data$n_ae,
-      .data$visit
-    ) %>%
+    select(c(
+      "study_id",
+      "site_number",
+      "patnum",
+      "n_ae",
+      "visit"
+    )) %>%
     arrange(.data$study_id, .data$site_number, .data$patnum, .data$visit)
 
   if (nrow(df_visit_out) > nrow(df_visit)) {
@@ -291,15 +291,15 @@ get_visit_med75 <- function(df_pat,
           .data$visit_med75
         )
       ) %>%
-      select(- .data$study_qup8_max_visit)
+      select(- "study_qup8_max_visit")
   }
 
   df_site <- df_site %>%
-    select(.data$study_id,
-           .data$site_number,
-           .data$n_pat,
-           .data$n_pat_with_med75,
-           .data$visit_med75)
+    select(c("study_id",
+             "site_number",
+             "n_pat",
+             "n_pat_with_med75",
+             "visit_med75"))
 
   return(df_site)
 }
@@ -309,6 +309,7 @@ get_visit_med75 <- function(df_pat,
 #' @param df_sim_sites dataframe generated by \code{\link[simaerep]{sim_sites}}
 #' @param method character, passed to stats::p.adjust(), if NULL
 #' eval_sites_deprecated() is used instead, Default = "BH"
+#' @inheritParams sim_sites
 #' @param ... use to pass r_sim_sites parameter to eval_sites_deprecated()
 #' @return dataframe with the following columns:
 #' \describe{
@@ -347,6 +348,7 @@ get_visit_med75 <- function(df_pat,
 #' @export
 eval_sites <- function(df_sim_sites,
                         method = "BH",
+                        under_only = TRUE,
                         ...) {
 
 
@@ -406,6 +408,24 @@ eval_sites <- function(df_sim_sites,
         prob_low_adj = p.adjust(.data$prob_low, method = method),
         prob_low_prob_ur = 1 - .data$prob_low_adj
       )
+
+    if (! under_only) {
+      df_out <- df_out %>%
+        mutate(
+          prob_high = 1 - .data$prob_low,
+          prob_high = ifelse(
+            .data$mean_ae_site_med75 == .data$mean_ae_study_med75,
+            1,
+            .data$prob_high
+          )
+        ) %>%
+        arrange(.data$study_id, .data$prob_high) %>%
+        mutate(
+          prob_high_adj = p.adjust(.data$prob_high, method = method),
+          prob_high_prob_or = 1 - .data$prob_high_adj
+        )
+    }
+
   }
 
   return(ungroup(df_out))
@@ -486,7 +506,7 @@ eval_sites_deprecated <- function(df_sim_sites,
         pval_p_vs_fp_ratio = ifelse(.data$pval_p_vs_fp_ratio < 1, 1, .data$pval_p_vs_fp_ratio),
         pval_prob_ur = 1 - 1 / .data$pval_p_vs_fp_ratio
       ) %>%
-      select(- .data$min_pval)
+      select(- "min_pval")
   }
 
   if ("prob_low" %in% names(df_out)) {
@@ -575,20 +595,20 @@ get_ecd_values <- function(df_sim_studies, df_sim_sites, val_str) {
 
   df_ecd <- df_sim_studies %>%
     rename(val = !!as.symbol(val_str)) %>%
-    select(.data$study_id, .data$val) %>%
-    nest(data = c(.data$val)) %>%
+    select("study_id", "val") %>%
+    nest(data = "val") %>%
     mutate(.ecdf = map(.data$data, ~ possibly_ecdf(.$val))) %>%
-    select(- .data$data)
+    select(- "data")
 
   df_out <- df_sim_sites %>%
     rename(val = !!as.symbol(val_str)) %>%
     left_join(df_ecd, "study_id") %>%
     mutate(ecd_val = map2_dbl(.data$`.ecdf`, .data$val, apply_ecdf)) %>%
     rename(
-      !!as.symbol(val_str) := .data$val,
-      !!as.symbol(paste0(val_str, "_ecd")) := .data$ecd_val #nolint
+      !!as.symbol(val_str) := "val",
+      !!as.symbol(paste0(val_str, "_ecd")) := "ecd_val" #nolint
     ) %>%
-    select(- .data$`.ecdf`)
+    select(- ".ecdf")
 
   return(ungroup(df_out))
 }
@@ -628,11 +648,11 @@ pat_pool <- function(df_visit, df_site) {
   df_visit %>%
     left_join(df_site, by = c("study_id", "site_number")) %>%
     filter(.data$visit <= .data$max_visit_med75_study) %>%
-    select(.data$study_id,
-           .data$patnum,
-           .data$visit,
-           .data$n_ae) %>%
-    nest(pat_pool = c(.data$patnum, .data$visit, .data$n_ae))
+    select(c("study_id",
+           "patnum",
+           "visit",
+           "n_ae")) %>%
+    nest(pat_pool = c("patnum", "visit", "n_ae"))
 }
 
 
@@ -644,6 +664,7 @@ pat_pool <- function(df_visit, df_site) {
 #' @param study_ae vector with AE numbers
 #' @param r integer, denotes number of simulations, default = 1000
 #' @param parallel logical, toggles parallel processing on and of, default = F
+#' @param under_only compute under-reporting probabilities only, default = TRUE
 #' @return pval
 #' @details sets pvalue=1 if mean AE site is greater than mean AE study
 #' @examples
@@ -655,8 +676,7 @@ pat_pool <- function(df_visit, df_site) {
 #' @seealso \code{\link[purrr]{safely}}
 #' @rdname prob_lower_site_ae_vs_study_ae
 #' @export
-prob_lower_site_ae_vs_study_ae <- function(site_ae, study_ae, r = 1000, parallel = FALSE) {
-
+prob_lower_site_ae_vs_study_ae <- function(site_ae, study_ae, r = 1000, parallel = FALSE, under_only = TRUE) {
   # if there is only one site
   if (is.null(study_ae)) {
     prob_lower <- 1
@@ -666,12 +686,15 @@ prob_lower_site_ae_vs_study_ae <- function(site_ae, study_ae, r = 1000, parallel
   mean_ae_site <- mean(site_ae, na.rm = TRUE)
   mean_ae_study <- mean(study_ae, na.rm = TRUE)
 
-  # we are not interested in cases where site AE is greater study AE
-  if (mean_ae_site > mean_ae_study) {
-    prob_lower <- 1
-    return(prob_lower)
+  if (under_only) {
+    # we are not interested in cases where site AE is greater study AE
+    if (mean_ae_site > mean_ae_study) {
+      prob_lower <- 1
+      return(prob_lower)
+    }
   }
 
+
   # set-up multiprocessing
   # multiprocessing currently not used by sim_sites()
   if (parallel) {
@@ -711,6 +734,7 @@ prob_lower_site_ae_vs_study_ae <- function(site_ae, study_ae, r = 1000, parallel
 #' @param prob_lower logical, calculates probability for getting a lower value
 #' @param progress logical, display progress bar, Default = TRUE
 #' @param check, logical, perform data check and attempt repair with
+#' @param under_only compute under-reporting probabilities only, default = TRUE
 #'  [check_df_visit()][check_df_visit], computationally expensive on large data
 #'  sets. Default: TRUE
 #' @return dataframe with the following columns:
@@ -757,7 +781,8 @@ sim_sites <- function(df_site,
                       poisson_test = TRUE,
                       prob_lower = TRUE,
                       progress = TRUE,
-                      check = TRUE) {
+                      check = TRUE,
+                      under_only = TRUE) {
   if (check) {
     df_visit <- check_df_visit(df_visit)
   }
@@ -768,7 +793,8 @@ sim_sites <- function(df_site,
                            r = r,
                            poisson_test = poisson_test,
                            prob_lower = prob_lower,
-                           progress = progress)
+                           progress = progress,
+                           under_only = under_only)
 
   return(df_sim)
 }
@@ -829,8 +855,7 @@ prep_for_sim <- function(df_site, df_visit) {
       n_ae_site = map(.data$n_ae_site, "n_ae"),
       n_ae_study = map(.data$n_ae_study, "n_ae")
     ) %>%
-    select(- .data$patients,
-           - .data$pat_pool)
+    select(- c("patients", "pat_pool"))
 
   return(df_sim_prep)
 
@@ -868,8 +893,8 @@ sim_after_prep <- function(df_sim_prep,
                            r = 1000,
                            poisson_test = FALSE,
                            prob_lower = TRUE,
-                           progress = FALSE) {
-
+                           progress = FALSE,
+                           under_only = TRUE) {
   df_sim <- df_sim_prep
 
   if (poisson_test) {
@@ -886,7 +911,7 @@ sim_after_prep <- function(df_sim_prep,
             .data$n_ae_site, .data$n_ae_study,
             .purrr = map2_dbl,
             .f = prob_lower_site_ae_vs_study_ae,
-            .f_args = list(r = r),
+            .f_args = list(r = r, under_only = under_only),
             .steps = nrow(df_sim),
             .progress = progress
           )
@@ -908,15 +933,15 @@ sim_after_prep <- function(df_sim_prep,
           ~ ifelse(.data$n_pat_with_med75_study == 0, NA, .)
         )
     ) %>%
-    select(- .data$n_ae_site, - .data$n_ae_study) %>%
-    select(.data$study_id,
-           .data$site_number,
-           .data$n_pat,
-           .data$n_pat_with_med75,
-           .data$visit_med75,
-           .data$mean_ae_site_med75,
-           .data$mean_ae_study_med75,
-           .data$n_pat_with_med75_study,
+    select(- c("n_ae_site", "n_ae_study")) %>%
+    select(c("study_id",
+           "site_number",
+           "n_pat",
+           "n_pat_with_med75",
+           "visit_med75",
+           "mean_ae_site_med75",
+           "mean_ae_study_med75",
+           "n_pat_with_med75_study"),
            dplyr::everything()) %>%
     ungroup()
 
@@ -976,11 +1001,11 @@ sim_after_prep <- function(df_sim_prep,
 get_pat_pool_config <- function(df_visit, df_site, min_n_pat_with_med75 = 1) {
 
   # site_config are the number of sites with their individual visit_med75 and n_pat_with_med75
-  df_site_config <- select(df_site,
-                           .data$study_id,
-                           .data$site_number,
-                           .data$visit_med75,
-                           .data$n_pat_with_med75) %>%
+  df_site_config <- select(df_site, c(
+                           "study_id",
+                           "site_number",
+                           "visit_med75",
+                           "n_pat_with_med75")) %>%
     filter(.data$n_pat_with_med75 >= min_n_pat_with_med75)
 
   # pat_pool gives the patient pool for study from which we sample
@@ -994,12 +1019,12 @@ get_pat_pool_config <- function(df_visit, df_site, min_n_pat_with_med75 = 1) {
       pat_pool = map2(.data$pat_pool, .data$visit_med75, function(x, y) filter(x, visit == y)),
       n_pat_study = map2_dbl(.data$pat_pool, .data$n_pat_with_med75, function(x, y) nrow(x) - y)
     ) %>%
-    select(.data$study_id,
-           .data$site_number,
-           .data$visit_med75,
-           .data$n_pat_with_med75,
-           .data$n_pat_study,
-           .data$pat_pool)
+    select(c("study_id",
+           "site_number",
+           "visit_med75",
+           "n_pat_with_med75",
+           "n_pat_study",
+           "pat_pool"))
 
   return(ungroup(df_site_config))
 }
@@ -1019,6 +1044,8 @@ get_pat_pool_config <- function(df_visit, df_site, min_n_pat_with_med75 = 1) {
 #' @param r integer, denotes number of simulations, Default: 1000
 #' @param r_prob_lower integer, denotes number of simulations for prob_lower
 #'   value calculation,, Default: 1000
+#' @param under_only compute under-reporting probabilities only, default = TRUE
+#' @param under_only compute under-reporting probabilities only, default = TRUE
 #' @param poisson_test logical, calculates poisson.test pvalue, Default: TRUE
 #' @param prob_lower logical, calculates probability for getting a lower value,
 #'   Default: FALSE
@@ -1064,6 +1091,7 @@ sim_studies <- function(df_visit,
                         poisson_test = TRUE,
                         prob_lower = TRUE,
                         r_prob_lower = 1000,
+                        under_only = TRUE,
                         parallel = FALSE,
                         keep_ae = FALSE,
                         min_n_pat_with_med75 = 1,
@@ -1113,7 +1141,7 @@ sim_studies <- function(df_visit,
                           function(x, y) sample_n(x, y, replace = TRUE)),
         n_ae_study = map(.data$n_ae_study, "n_ae")
       ) %>%
-      select(- .data$pat_pool)
+      select(- "pat_pool")
 
     if (poisson_test) {
       df_config <- df_config %>%
@@ -1127,15 +1155,16 @@ sim_studies <- function(df_visit,
       df_config <- df_config %>%
         mutate(prob_low = map2_dbl(.data$n_ae_site, .data$n_ae_study,
                                    prob_lower_site_ae_vs_study_ae,
-                                   r = r_prob_lower))
+                                   r = r_prob_lower,
+                                   under_only = under_only))
     }
 
     if (!keep_ae) {
       df_config <- df_config %>%
-        select(- .data$n_ae_site, - .data$n_ae_study)
+        select(- c("n_ae_site", "n_ae_study"))
     } else {
       df_config <- df_config %>%
-        mutate_at(vars(n_ae_site, n_ae_study), ~ map_chr(., paste, collapse = ","))
+        mutate_at(vars(c("n_ae_site", "n_ae_study")), ~ map_chr(., paste, collapse = ","))
     }
 
     return(ungroup(df_config))
@@ -1143,7 +1172,7 @@ sim_studies <- function(df_visit,
 
   df_sim <- tibble(r = seq.int(1, r, 1)) %>%
     mutate(n_ae_set = .f_map(.data$r, sim)) %>%
-    unnest(.data$n_ae_set)
+    unnest("n_ae_set")
 
   return(ungroup(df_sim))
 }
@@ -1220,10 +1249,10 @@ site_aggr <- function(df_visit,
 
   df_mean_ae_med75 <- df_mean_ae_dev %>%
     filter(.data$visit == .data$visit_med75) %>%
-    rename(mean_ae_site_med75 = .data$mean_ae_site) %>%
-    select(.data$study_id,
-           .data$site_number,
-           .data$mean_ae_site_med75)
+    rename(mean_ae_site_med75 = "mean_ae_site") %>%
+    select(c("study_id",
+           "site_number",
+           "mean_ae_site_med75"))
 
   # Add mean cumulative AE to site aggregate ----------------------
 
